@@ -2,10 +2,8 @@
 #'
 #' @param .data \code{list}
 #' @param expr A lambda expression
-#' @name list.common
 #' @export
 #' @examples
-#' \dontrun{
 #' x <- list(c("a","b","c"),c("a","b"),c("b","c"))
 #' list.common(x, .)
 #' x <- list(p1 = list(type="A",score=list(c1=10,c2=8)),
@@ -13,9 +11,8 @@
 #'        p3 = list(type="B",score=list(c1=9,c2=7)))
 #' list.common(x,type)
 #' list.common(x,names(score))
-#' }
 list.common <- function(.data,expr) {
   if(length(.data) == 0L) return(NULL)
-  values <- list.map.internal(.data,substitute(expr),envir = parent.frame())
-  Reduce(intersect,values,values[[1L]])
+  values <- list.map.internal(.data, substitute(expr), parent.frame())
+  reduce(intersect, values, values[[1L]])
 }
