@@ -2,10 +2,8 @@
 #'
 #' @param x \code{The object}
 #' @param ... Additional parameters
-#' @name list.parse
 #' @export
 #' @examples
-#' \dontrun{
 #' x <- data.frame(a=1:3,type=c("A","C","B"))
 #' list.parse(x)
 #'
@@ -21,7 +19,6 @@
 #'   registered: yes
 #' "
 #' list.parse(z,type="yaml")
-#' }
 list.parse <- function(x,...)
   UseMethod("list.parse")
 
@@ -41,32 +38,32 @@ list.parse.matrix <- function(x,...) {
 #' @rdname list.parse
 list.parse.data.frame <- function(x,...) {
   cols <- colnames(x)
-  items <- do.call(Map,c(function(...) {
-   setnames(list(...),cols)
+  items <- do.call(map,c(function(...) {
+    setnames(list(...),cols)
   },x))
   setnames(items,rownames(x))
 }
 
 #' @export
 #' @rdname list.parse
-#' @param type The type of data to parse.
-#'    Currently json and yaml are supported.
-#'    In default, \code{NULL} value will parse the character with
-#'    \code{list.parse.default}. Ignored when the length of \code{x}
-#'    is greater than 1.
-list.parse.character <- function(x,...,type=NULL) {
-  if(length(x) > 1L) return(list.parse.default(x,...))
-  if(is.null(type)) {
-    list.parse.default(x,...)
-  } else if(tolower(type)=="yaml") {
-    yaml::yaml.load(x,...)
-  } else if(tolower(type)=="json") {
-    jsonlite::fromJSON(x,
-      simplifyVector = FALSE,
-      simplifyDataFrame = FALSE,
-      simplifyMatrix = FALSE,...)
-  } else {
-    stop("Invalid type of data")
+#' @param type The type of data to parse. Currently json and yaml are supported.
+list.parse.character <- function(x, type = NA, ...) {
+  if(length(x) == 0L) return(list())
+  else if(length(x) == 1L) {
+    if(missing(type) || length(type) == 0L || is.na(type)) {
+      list.parse.default(x, ...)
+    } else if(tolower(type)=="yaml") {
+      yaml::yaml.load(x,...)
+    } else if(tolower(type)=="json") {
+      callwith(jsonlite::fromJSON,
+        list(x, simplifyVector = FALSE,
+          simplifyDataFrame = FALSE,
+          simplifyMatrix = FALSE), list(...))
+    } else {
+      stop("Invalid type of data")
+    }
+  } else if(length(x) > 1L) {
+    map(list.parse.character, x, type = type, MoreArgs = list(...),
+      USE.NAMES = !is.null(names(x)))
   }
 }
-
