@@ -52,8 +52,7 @@ test_that("list.subset", {
     p2 = list(type="B",score=list(c1=9,c2=9)),
     p3 = list(type="B",score=list(c1=9,c2=7)))
   expect_identical(list.subset(x, c("p1","p2")),x[c("p1","p2")])
-  expect_identical(list.subset(x, "^p", pattern = TRUE),x[])
-  expect_identical(list.subset(x, "x1", dist = 1),x["p1"])
+  expect_identical(list.subset(x, grepl("^p", names(x))),x[])
 })
 
 test_that("list.count", {
@@ -120,6 +119,8 @@ test_that("list.cbind", {
 test_that("list.stack", {
   x <- lapply(1:10,function(i) list(a=i,b=i^2))
   expect_false(is.null(list.stack(x)))
+  x <- lapply(1:10,function(i) list(a=c(i,i+1),b=c(i^2,i^2+1)))
+  expect_false(is.null(list.stack(x)))
 })
 
 test_that("list.match", {
@@ -194,6 +195,12 @@ test_that("list.all", {
   expect_equal(list.all(x,type=="B"),FALSE)
   expect_equal(list.all(x,mean(unlist(score))>=6),TRUE)
   expect_equal(sapply(8:10,function(i) list.all(x,score$c1>=i)),c(T,T,F))
+  expect_equal(list.all(logical()), all())
+  expect_equal(list.all(logical(), na.rm = TRUE), all(na.rm = TRUE))
+  expect_equal(list.all(c(TRUE, NA, TRUE)), all(c(TRUE, NA, TRUE)))
+  expect_equal(list.all(c(TRUE, NA, FALSE)), all(c(TRUE, NA, FALSE)))
+  expect_equal(list.all(c(TRUE, NA, TRUE), na.rm = TRUE), all(c(TRUE, NA, TRUE), na.rm = TRUE))
+  expect_equal(list.all(c(TRUE, NA, FALSE), na.rm = TRUE), all(c(TRUE, NA, FALSE), na.rm = TRUE))
 })
 
 test_that("list.any", {
@@ -203,6 +210,30 @@ test_that("list.any", {
   expect_equal(list.any(x,type=="B"),TRUE)
   expect_equal(list.any(x,mean(unlist(score))>=20),FALSE)
   expect_equal(sapply(8:10,function(i) list.any(x,score$c1>=i)),c(T,T,T))
+  expect_equal(list.any(logical()), any())
+  expect_equal(list.any(logical(), na.rm = TRUE), any(na.rm = TRUE))
+  expect_equal(list.any(c(TRUE, NA, TRUE)), any(c(TRUE, NA, TRUE)))
+  expect_equal(list.any(c(TRUE, NA, FALSE)), any(c(TRUE, NA, FALSE)))
+  expect_equal(list.any(c(TRUE, NA, TRUE), na.rm = TRUE), any(c(TRUE, NA, TRUE), na.rm = TRUE))
+  expect_equal(list.any(c(TRUE, NA, FALSE), na.rm = TRUE), any(c(TRUE, NA, FALSE), na.rm = TRUE))
+})
+
+test_that("list.first", {
+  x <- list(p1 = list(type="A",score=list(c1=10,c2=8)),
+    p2 = list(type="B",score=list(c1=9,c2=9)),
+    p3 = list(type="B",score=list(c1=9,c2=7)))
+  expect_equal(list.first(x, type=="B"),x[[2L]])
+  expect_equal(list.first(x, unlist(score$c1 <= 9)),x[[2L]])
+  expect_identical(list.first(x, score$c1 < 9 || score$c3 >= 5), NULL)
+})
+
+test_that("list.last", {
+  x <- list(p1 = list(type="A",score=list(c1=10,c2=8)),
+    p2 = list(type="B",score=list(c1=9,c2=9)),
+    p3 = list(type="B",score=list(c1=9,c2=7)))
+  expect_equal(list.last(x,type=="B"),x[[3L]])
+  expect_equal(list.last(x,unlist(score$c1 <= 9)),x[[3L]])
+  expect_identical(list.last(x, score$c1 < 9 || score$c3 >= 5), NULL)
 })
 
 test_that("list.table", {
@@ -213,6 +244,9 @@ test_that("list.table", {
   x.c1 <- c(10,9,9)
   expect_identical(list.table(x,type),table(type=x.types))
   expect_identical(list.table(x,type,c1=score$c1),table(type=x.types,c1=x.c1))
+
+  x <- list(list(a=1,b=NULL), list(a=2,b=1), list(a=3,b=1))
+  expect_identical(as.integer(list.table(x, a, b)), c(0L,1L,1L,1L,0L,0L))
 })
 
 test_that("list.zip", {
@@ -221,8 +255,29 @@ test_that("list.zip", {
   expect_identical(list.zip(a,b),list(list(a=1,b="a"),list(a=2,b="b")))
 })
 
+test_that("list.unzip", {
+  x <- list(p1 = list(a = 1, b = 5), p2 = list(a = 2, b = 3))
+  x1 <- list(p1 = list(a = 1, b = 5), p2 = list(a = 2, b = 3, c = 4))
+  expect_identical(list.unzip(x), list(a = c(p1 = 1, p2 = 2), b = c(p1 = 5, p2 = 3)))
+  expect_identical(list.unzip(x1, .fields = "union"),
+    list(a = c(p1 = 1, p2 = 2), b = c(p1 = 5, p2 = 3), c = c(p1 = NA, p2 = 4)))
+  expect_identical(list.unzip(x, a = "identity"),
+    list(a = list(p1 = 1, p2 = 2), b = c(p1 = 5, p2 = 3)))
+  expect_identical(list.unzip(x, a = NULL),
+    list(b = c(p1 = 5, p2 = 3)))
+})
+
 test_that("list.flatten", {
   p <- list(a=1,b=list(b1=2,b2=3),c=list(c1=list(c11="a",c12="x"),c2=3))
+  q <- list(a=c(1,2,3),b=list(x=1,y=list(z=1,z2=2)))
   expect_identical(list.flatten(p),list(a=1,b.b1=2,b.b2=3,c.c1.c11="a",
     c.c1.c12="x",c.c2=3))
+  expect_identical(list.flatten(q),list(a=c(1,2,3),b.x=1,b.y.z=1,b.y.z2=2))
+})
+
+test_that("list.names", {
+  expect_identical(list.names(list(a=1,b=2)),c("a","b"))
+  expect_identical(list.names(list(1,2)),NULL)
+  expect_identical(list.names(list(1,2),letters[.]),list(a=1,b=2))
+  expect_identical(list.names(list(a=1,b=2),NULL),list(1,2))
 })
